pub struct VariantRet {
pub path: Path,
pub indices: Indices,
}Fields
path: Pathindices: IndicesBinders are not allowed at this position, but we parse this as a list of indices for better error reporting.